#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_BUTTONS (adap_demo_page_buttons_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageButtons, adap_demo_page_buttons, ADAP, DEMO_PAGE_BUTTONS, AdapBin)

G_END_DECLS
