#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_ANIMATIONS (adap_demo_page_animations_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageAnimations, adap_demo_page_animations, ADAP, DEMO_PAGE_ANIMATIONS, AdapBin)

G_END_DECLS
