#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_CAROUSEL (adap_demo_page_carousel_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageCarousel, adap_demo_page_carousel, ADAP, DEMO_PAGE_CAROUSEL, AdapBin)

G_END_DECLS
