#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_DIALOGS (adap_demo_page_dialogs_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageDialogs, adap_demo_page_dialogs, ADAP, DEMO_PAGE_DIALOGS, AdapBin)

G_END_DECLS
