#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_STYLES (adap_demo_page_styles_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageStyles, adap_demo_page_styles, ADAP, DEMO_PAGE_STYLES, AdapBin)

G_END_DECLS
