#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_ABOUT (adap_demo_page_about_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageAbout, adap_demo_page_about, ADAP, DEMO_PAGE_ABOUT, AdapBin)

G_END_DECLS
