.docs-background {
  background: alpha(currentColor, .05);
  border-radius: 12px;
}

#opaque-button-1 {
  color: @success_fg_color;
  background-color: @success_bg_color;
}

#opaque-button-2 {
  color: @warning_fg_color;
  background-color: @warning_bg_color;
}

#vscroll {
  padding-top: 12px;
  padding-bottom: 12px;
}

#hscroll {
  padding-left: 12px;
  padding-right: 12px;
}

.overview-tab-page {
  background: linear-gradient(to bottom right, @blue_1 25%, @green_1);
}
