// Sass thinks we're using the colors in the variables as strings and may shoot
// warning, it's innocuous and can be defeated by using #{$var}.

/* Public colors from Default */

@define-color theme_bg_color #{$window_bg_color};
@define-color theme_fg_color #{$window_fg_color};

@define-color theme_base_color #{$view_bg_color};
@define-color theme_text_color #{$view_fg_color};

@define-color theme_selected_bg_color #{$accent_bg_color};
@define-color theme_selected_fg_color #{$accent_fg_color};

@define-color insensitive_bg_color #{gtkmix($window_bg_color, $view_bg_color, 60%)};
@define-color insensitive_fg_color #{gtkalpha($window_fg_color, .5)};

@define-color insensitive_base_color #{$view_bg_color};

@define-color borders #{$border_color};

@define-color theme_unfocused_bg_color #{$window_bg_color};
@define-color theme_unfocused_fg_color #{$window_fg_color};

@define-color theme_unfocused_base_color #{$view_bg_color};
@define-color theme_unfocused_text_color #{$view_fg_color};

@define-color theme_unfocused_selected_bg_color #{$accent_bg_color};
@define-color theme_unfocused_selected_fg_color #{$accent_fg_color};

@define-color unfocused_insensitive_color #{gtkcolor(insensitive_bg_color)};

@define-color unfocused_borders #{$border_color};
