#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_BANNERS (adap_demo_page_banners_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageBanners, adap_demo_page_banners, ADAP, DEMO_PAGE_BANNERS, AdapBin)

G_END_DECLS
