#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_VIEW_SWITCHER (adap_demo_page_view_switcher_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageViewSwitcher, adap_demo_page_view_switcher, ADAP, DEMO_PAGE_VIEW_SWITCHER, AdapBin)

G_END_DECLS
