#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_NAVIGATION_VIEW (adap_demo_page_navigation_view_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageNavigationView, adap_demo_page_navigation_view, ADAP, DEMO_PAGE_NAVIGATION_VIEW, AdapBin)

G_END_DECLS
