#pragma once

#include <adapta.h>

G_BEGIN_DECLS

#define ADAP_TYPE_DEMO_PAGE_SPLIT_VIEWS (adap_demo_page_split_views_get_type())

G_DECLARE_FINAL_TYPE (AdapDemoPageSplitViews, adap_demo_page_split_views, ADAP, DEMO_PAGE_SPLIT_VIEWS, AdapBin)

G_END_DECLS
